X-Git-Url: https://git.rapsys.eu/packbundle/blobdiff_plain/0d6adabf6050f4496f683fab894e0da5ac42d57b..b69214e3aa8c18b333a58b160aa22fa2c356065f:/Extension/PackExtension.php

diff --git a/Extension/PackExtension.php b/Extension/PackExtension.php
index 118de0c..bbf166e 100644
--- a/Extension/PackExtension.php
+++ b/Extension/PackExtension.php
@@ -16,85 +16,77 @@ use Symfony\Component\DependencyInjection\ContainerInterface;
 use Symfony\Component\HttpKernel\Config\FileLocator;
 use Twig\Extension\AbstractExtension;
 
-use Rapsys\PackBundle\Util\SluggerUtil;
 use Rapsys\PackBundle\Parser\TokenParser;
+use Rapsys\PackBundle\RapsysPackBundle;
+use Rapsys\PackBundle\Util\IntlUtil;
+use Rapsys\PackBundle\Util\SluggerUtil;
 
 /**
  * {@inheritdoc}
  */
 class PackExtension extends AbstractExtension {
-	//The config
-	private $config;
-
-	//The output
-	private $output;
-
-	//The filter
-	private $filters;
-
-	//The file locator
-	protected $locator;
+	/**
+	 * The filters array
+	 */
+	protected array $filters;
 
-	//The slugger instance
-	protected $slugger;
+	/**
+	 * The output array
+	 */
+	protected array $output;
 
-	//The assets package
-	protected $package;
+	/**
+	 * The token string
+	 */
+	protected string $token;
 
 	/**
 	 * @link https://twig.symfony.com/doc/2.x/advanced.html
 	 *
 	 * {@inheritdoc}
 	 */
-	public function __construct(FileLocator $locator, ContainerInterface $container, PackageInterface $package, SluggerUtil $slugger) {
-		//Set file locator
-		$this->locator = $locator;
-
-		//Set slugger
-		$this->slugger = $slugger;
-
-		//Set assets packages
-		$this->package = $package;
-
+	public function __construct(protected ContainerInterface $container, protected IntlUtil $intl, protected FileLocator $locator, protected PackageInterface $package, protected SluggerUtil $slugger) {
 		//Retrieve bundle config
-		if ($parameters = $container->getParameter($this->getAlias())) {
-			//Set config, output and filters arrays
-			foreach(['config', 'output', 'filters'] as $k) {
+		if ($parameters = $container->getParameter(RapsysPackBundle::getAlias())) {
+			//Set filters, output arrays and token string
+			foreach(['filters', 'output', 'token'] as $k) {
 				$this->$k = $parameters[$k];
 			}
 		}
 	}
 
 	/**
 	 * Returns a list of filters to add to the existing list.
 	 *
 	 * @return \Twig\TwigFilter[]
 	 */
 	public function getTokenParsers(): array {
 		return [
-			new TokenParser($this->locator, $this->package, $this->config, 'stylesheet', $this->output['css'], $this->filters['css']),
-			new TokenParser($this->locator, $this->package, $this->config, 'javascript', $this->output['js'], $this->filters['js']),
-			new TokenParser($this->locator, $this->package, $this->config, 'image', $this->output['img'], $this->filters['img'])
+			new TokenParser($this->locator, $this->package, $this->token, 'stylesheet', $this->output['css'], $this->filters['css']),
+			new TokenParser($this->locator, $this->package, $this->token, 'javascript', $this->output['js'], $this->filters['js']),
+			new TokenParser($this->locator, $this->package, $this->token, 'image', $this->output['img'], $this->filters['img'])
 		];
 	}
 
 	/**
 	 * Returns a list of filters to add to the existing list.
 	 *
 	 * @return \Twig\TwigFilter[]
 	 */
 	public function getFilters(): array {
 		return [
+			new \Twig\TwigFilter('lcfirst', 'lcfirst'),
+			new \Twig\TwigFilter('ucfirst', 'ucfirst'),
 			new \Twig\TwigFilter('hash', [$this->slugger, 'hash']),
 			new \Twig\TwigFilter('unshort', [$this->slugger, 'unshort']),
-			new \Twig\TwigFilter('short', [$this->slugger, 'short'])
+			new \Twig\TwigFilter('short', [$this->slugger, 'short']),
+			new \Twig\TwigFilter('slug', [$this->slugger, 'slug']),
+			new \Twig\TwigFilter('intldate', [$this->intl, 'date'], ['needs_environment' => true]),
+			new \Twig\TwigFilter('intlnumber', [$this->intl, 'number']),
+			new \Twig\TwigFilter('intlcurrency', [$this->intl, 'currency']),
+			new \Twig\TwigFilter('download', 'file_get_contents', [false, null]),
+			new \Twig\TwigFilter('base64_encode', 'base64_encode'),
+			new \Twig\TwigFilter('base64_decode', 'base64_decode')
 		];
 	}
-
-	/**
-	 * {@inheritdoc}
-	 */
-	public function getAlias(): string {
-		return 'rapsys_pack';
-	}
 }
@@ -16,85 +16,77 @@ use Symfony\Component\DependencyInjection\ContainerInterface;
 
 	/**
-	 * Returns a list of filters to add to the existing list.
+	 * Returns a filter array to add to the existing list.
 	 *
 	 * @return \Twig\TwigFilter[]
@@ -16,85 +16,77 @@ use Symfony\Component\DependencyInjection\ContainerInterface;
 
 	/**
-	 * Returns a list of filters to add to the existing list.
+	 * Returns a filter array to add to the existing list.
 	 *
 	 * @return \Twig\TwigFilter[]